package fit.asympdist;

import fit.utils.DoublePair;

/**
 * Interface for the distribution of asymptotes.
 */
public interface AsympDist {

    /**
     * Returns parameter length.
     * @return Number of parameters.
     */
    public int paramLen();

    /**
     * Inversed CDF. For calculating percentile values.
     * @param _p Cumulative probability value.
     * @param _Params Disribution parameters.
     * @return The value inverse CDF.
     */
    public double InvCDF(double _p, double... _Params);

    /**
     * Returns maximum log likelihood and MLE-estimated parameters.
     *
     * @param _V Random variables.
     * @return logML, {Params...}.
     */
    public DoublePair MLE(double[] _V);

     /**
     * Returns logarithmic PDF.
     *
     * @param _x Random variable.
     * @param _Params Disribution parameters.
     * @return The value of logPDF
     */
    public double logPDF(double _x, double... _Params);
}
