package fit.utils;

import java.util.Random;
import org.apache.commons.math3.random.Well19937c;

/**
 * Class for pseudo random numbers. A Well19937c instance is wrapped. Each instance is initialized with a meta seed generator sequence for multithread computing
 * and reproductivity.
 */
public class Rand {

    //Random seed generator.
    private static final Random SEEDGEN;

    //Meta seed of the random seed generator.
    private static final long META_SEED_GEN = Long.parseLong("010101010101010101010101010101010101010101010101010101010101010", 2);

    //Sets the meta seed first.
    static {
        SEEDGEN = new Random(META_SEED_GEN);
    }

    //Random number generator of each instance.
    private final Well19937c well;

    /**
     * Constructor.
     */
    public Rand() {
        synchronized (SEEDGEN) {
            well = new Well19937c(SEEDGEN.nextLong());
        }
    }

    /**
     * Copy function.
     *
     * @return New Rand object.
     */
    public Rand copy() {
        return new Rand();
    }

    /**
     * @return Random number in [0, 1].
     */
    public final double runif() {
        return well.nextDouble();
    }

    /**
     * Fills random numbers to a given array.
     *
     * @param D The array to fill random numbers.
     */
    public final void fill(double[] D) {
        for (int i = 0; i < D.length; i++) D[i] = well.nextDouble();
    }
}
