package main;

import fit.Fit;
import fit.asympdist.AsympDist_GGD;
import fit.asympdist.AsympDist_LogNormal;
import fit.growth.Growth_Anamorphic;
import fit.growth.Growth_Polymorphic;
import fit.utils.FileHandler;
import fit.utils.PSO;
import fit.utils.Rand;
import java.io.IOException;

/**
 * Class to estimate the model for a prepared data. The file to be prepared should be a csv file constructed as follows:
 * <pre>
 *
 * T,H                            The first row should be the header
 * 30,20.4
 * 14,13.3
 * 25,20.0
 * ...
 * Do not include rows that include missing data. When error occured, check your data file using a notepad application.
 * Using the data on Supplementary Tables 1 and 2 in Katakura et al. (2005), the results presented by Moriguchi (2020) is reproduced.
 * </pre>

 */
public class MainFit {

    /**
     * Set absolute file path of prepared filename (or place the file in the project directory). Fitting results are saved as csv files with prefix "ParamsOf_".
     */
    static final String filename = "TestData.csv"; //Put your data csv file name.

    public static void main(String... _args) throws IOException {
        System.setProperty("java.util.concurrent.ForkJoinPool.common.parallelism", "28");
        //Fitting methods to be attempted
        Fit[] F = {
            //The anamorphic model. Lower and upper limits of k and m.
            new Fit(new Growth_Anamorphic(), new AsympDist_LogNormal(), new double[]{1e-12, 0.01}, new double[]{0.1, 5}),
            new Fit(new Growth_Anamorphic(), new AsympDist_GGD(), new double[]{1e-12, 0.01}, new double[]{0.1, 5}),
            //The polymorphic model. Lower and upper limits of k, m and l.
            new Fit(new Growth_Polymorphic(), new AsympDist_LogNormal(), new double[]{1e-12, 0.01, -10}, new double[]{0.1, 5, 10}),
            new Fit(new Growth_Polymorphic(), new AsympDist_GGD(), new double[]{1e-12, 0.01, -10}, new double[]{0.1, 5, 10})
        };
        Rand r = new Rand();
        //Import data
        double[][] Original = FileHandler.getData(filename);
            for (int i = 0; i < F.length; i++) {
                F[i].setData(Original);
                PSO pso = new PSO(F[i]);
                pso.run();
                String str = FileHandler.getResult(0, pso);
                System.out.print(str);// Show result in the standard output
            }
    }

}
